// Copyright 2025 The Bazel Authors. All rights reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
package com.google.devtools.build.lib.skyframe.serialization;

import com.google.devtools.build.lib.skyframe.serialization.WriteStatuses.WriteStatus;

/** An interface for fingerprinting/key generation and writing key-value data. */
public interface KeyValueWriter extends Fingerprinter {

  /**
   * Stores the given serialized bytes under the key provided.
   *
   * @param key A provider for the key bytes.
   * @param serializedBytes The data to store.
   * @return A WriteStatus indicating the result of the put operation.
   */
  WriteStatus put(KeyBytesProvider key, byte[] serializedBytes);
}
